# frozen_string_literal: true

# Copyright from 2019 Paulo Arruda (parrudaj at gmail dot com)
#
# Licensed under the Commons Clause + Apache License, Version 2.0
# (the "License"); you may not use this file except in compliance with
# the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

require 'sinatra'
require 'sinatra/contrib'
require 'gotta/serve/version'
require 'gotta/common/project'
require 'gotta/queue/memory'

module Gotta
  module Serve
    project = Gotta::Project.new(Dir.pwd)
    Gotta::Project.config = project
    require 'gotta/serve/constants'

    class << self
      attr_accessor :input_queue, :queue_driver
    end

    def self.start!(config)
      queue_driver = Gotta::Queue::Memory::Driver
      input_queue = queue_driver.new('input')
      puts "Gotta running #{config.environment} environment."
      puts "Gotta visit #{config.scheme}://#{config.bind_address}:#{config.port}"
      ENV['ENVIRONMENT'] = config.environment
      require 'gotta/serve/app'
    end
  end
end
